#
# spec file for package python-sat-search
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define packagename sat-search
Name:           python-sat-search
Version:        0.3.0
Release:        3.1
Summary:        A tool for discovering and downloading publicly available satellite imagery
License:        MIT
URL:            https://github.com/sat-utils/sat-search
Source:         https://files.pythonhosted.org/packages/source/s/sat-search/sat-search-%{version}.tar.gz
Source99:       https://raw.githubusercontent.com/sat-utils/sat-search/master/LICENSE
# PATCH-FIX-UPSTREAM gh#sat-utils/sat-search#136
Patch0:         use-importlib.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 2.8.2}
BuildRequires:  %{python_module sat-stac}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-sat-stac
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Sat-search is a Python 3 library and a command line tool for discovering
and downloading publicly available satellite imagery using a conformant
API such as sat-api.

%prep
%autosetup -p1 -n %{packagename}-%{version}
cp %{SOURCE99} .

sed -i -e '/pytest-runner/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
for p in %{packagename} ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done
%python_expand rm -r %{buildroot}%{$python_sitelib}/test
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative %{packagename}

%post
%python_install_alternative %{packagename}

%postun
%python_uninstall_alternative %{packagename}

%check
# polls server for data for searching
#%%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/%{packagename}
%{python_sitelib}/satsearch
%{python_sitelib}/sat_search-%{version}.dist-info

%changelog
* Tue Dec 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- No longer skip building for Python 3.12.
- Switch to pyproject and autosetup macros.
- Add patch use-importlib.patch:
  * Use importlib, rather than imp.
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip build for python 3.12
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.3.0
  * Updated to work with STAC API v0.9.0 and v1.0.0-beta.2
  * SATUTILS_API_URL envvar changed to STAC_API_URL and default value removed. Specify with envvar or pass into Search when using library
  * When downloading, specify filename_template for location instead of both datadir and filename.
  * Update pagination to precisely follow STAC spec
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the download url
* Mon Aug 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in pytest-runner as it is deprecated
* Sat Aug  1 2020 andy great <andythe_great@pm.me>
- Update spec file to use python alternative.
* Sun Jul 26 2020 andy great <andythe_great@pm.me>
- Initial package release.
